emrpy.visualization.timeseries
==============================

.. automodule:: emrpy.visualization.timeseries


   .. rubric:: Functions

   .. autosummary::

      plot_multiple_log_returns
      plot_timeseries
